==> haskell-tasty-hunit-0.10.2-121.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.2
visibility:           public
id:                   tasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb
key:                  tasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  47ab59cd85f5bdbbc4a943ae5bb74b6a
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb
depends:
    base-4.18.2.1 call-stack-0.4.0-6YsJqSpqGk4Bu2nGz8R6vi
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.2-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.2
visibility:           public
id:                   tasty-hunit-0.10.2-96pg6B929I9E8nnywjEniv
key:                  tasty-hunit-0.10.2-96pg6B929I9E8nnywjEniv
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  a23e8974f065e572fada1f09866bf63c
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.2-96pg6B929I9E8nnywjEniv
depends:
    base-4.18.2.1 call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
